@@ -8,6 +8,6 @@ autoheader
 touch stamp-h
 autoconf
 libtoolize --copy --force --automake
-automake -a -c
+automake --add-missing --copy --force-missing
 glib-gettextize --copy --force
 intltoolize --automake --copy --force
