@@ -43,6 +43,7 @@
 #include <config.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib.h>
+#include <glib/gprintf.h>
 #include <gtk/gtk.h>
 #include <libintl.h>
 #include <locale.h>
@@ -267,10 +268,10 @@ destroy_popup(GtkWidget * widget, GtkWidget * popup)
 gboolean
 xproperty_exists(gchar * property)
 {
-    GdkAtom *actual_property_type;
-    gint *actual_format;
-    gint *actual_length;
-    guchar **data;
+    GdkAtom *actual_property_type = NULL;
+    gint *actual_format = 0;
+    gint *actual_length = 0;
+    guchar **data = NULL;
     gboolean result;
 
     result=gdk_property_get(
@@ -299,24 +300,24 @@ handle_command(GIOChannel * io_input)
 
     log_entry("gtkgreet",7,"Got command: %s",buf->str);
 
-    if (!g_strncasecmp(buf->str, "msg", 3)) {
+    if (!g_ascii_strncasecmp(buf->str, "msg", 3)) {
         gchar **split_buf;
         split_buf = g_strsplit(buf->str, " ", 2);
         gtk_label_set_markup((GtkLabel *) StatusMessages, split_buf[1]);
         g_strfreev(split_buf);
-    } else if (!g_strncasecmp(buf->str, "quit", 4)) {
+    } else if (!g_ascii_strncasecmp(buf->str, "quit", 4)) {
         if (!xproperty_exists("X11VNC_TICKER")) {
             GdkCursor *cursor;
             cursor = gdk_cursor_new(GDK_WATCH);
             gdk_window_set_cursor(gdk_get_default_root_window(), cursor);
         }
         gtk_main_quit();
-    } else if (!g_strncasecmp(buf->str, "prompt", 6)) {
+    } else if (!g_ascii_strncasecmp(buf->str, "prompt", 6)) {
         gchar **split_buf;
         split_buf = g_strsplit(buf->str, " ", 2);
         gtk_label_set_markup((GtkLabel *) UserPrompt, split_buf[1]);
         g_strfreev(split_buf);
-    } else if (!g_strncasecmp(buf->str, "userid", 6)) {
+    } else if (!g_ascii_strncasecmp(buf->str, "userid", 6)) {
         timeout_enabled = login_timeout > 0;
         if(timeout_enabled) {
             gtk_widget_show(timeoutbox);
@@ -327,7 +328,7 @@ handle_command(GIOChannel * io_input)
         gtk_entry_set_visibility(GTK_ENTRY(entry), TRUE);
         gtk_widget_set_sensitive(GTK_WIDGET(entry), TRUE);
         gtk_widget_set_sensitive(GTK_WIDGET(GuestButton), TRUE);
-    } else if (!g_strncasecmp(buf->str, "passwd", 6)) {
+    } else if (!g_ascii_strncasecmp(buf->str, "passwd", 6)) {
         timeout_enabled = FALSE;
         timeout_left = 0;
         gtk_widget_hide(timeoutbox);
@@ -335,7 +336,7 @@ handle_command(GIOChannel * io_input)
         gtk_entry_set_visibility(GTK_ENTRY(entry), FALSE);
         gtk_widget_set_sensitive(GTK_WIDGET(entry), TRUE);
         gtk_widget_set_sensitive(GTK_WIDGET(GuestButton), FALSE);
-    } else if (!g_strncasecmp(buf->str, "hostname", 8)) {
+    } else if (!g_ascii_strncasecmp(buf->str, "hostname", 8)) {
         gchar *hoststr;
         update_selected_host();
         hoststr = g_strdup_printf("%s\n", host);
@@ -344,21 +345,21 @@ handle_command(GIOChannel * io_input)
         g_free(hoststr);
         gtk_widget_set_sensitive(GTK_WIDGET(entry), FALSE);
         gtk_widget_set_sensitive(GTK_WIDGET(GuestButton), FALSE);
-    } else if (!g_strncasecmp(buf->str, "language", 8)) {
+    } else if (!g_ascii_strncasecmp(buf->str, "language", 8)) {
         gchar *langstr;
         update_selected_lang();
         langstr = g_strdup_printf("%s\n", language);
         g_io_channel_write_chars(g_stdout, langstr, -1, NULL, NULL);
         g_io_channel_flush(g_stdout, NULL);
         g_free(langstr);
-    } else if (!g_strncasecmp(buf->str, "session", 7)) {
+    } else if (!g_ascii_strncasecmp(buf->str, "session", 7)) {
         gchar *sessstr;
         update_selected_sess();
         sessstr = g_strdup_printf("%s\n", session);
         g_io_channel_write_chars(g_stdout, sessstr, -1, NULL, NULL);
         g_io_channel_flush(g_stdout, NULL);
         g_free(sessstr);
-    } else if (!g_strncasecmp(buf->str, "choice", 6)) {
+    } else if (!g_ascii_strncasecmp(buf->str, "choice", 6)) {
         int i;
         GtkTreeIter iter;
 
@@ -382,7 +383,7 @@ handle_command(GIOChannel * io_input)
 
         gtk_widget_hide(entry);
         gtk_widget_show(choiceCombo);
-    } else if (!g_strncasecmp(buf->str, "pref choice", 11)) {
+    } else if (!g_ascii_strncasecmp(buf->str, "pref choice", 11)) {
         int i;
 
         // strip newline char
@@ -405,7 +406,7 @@ handle_command(GIOChannel * io_input)
 
         g_strfreev(choices);
         g_strfreev(args);
-    } else if (!g_strncasecmp(buf->str, "value", 5)) {
+    } else if (!g_ascii_strncasecmp(buf->str, "value", 5)) {
         gchar *name = buf->str + 6;
         gchar *valstr;
 
@@ -417,9 +418,9 @@ handle_command(GIOChannel * io_input)
         g_io_channel_write_chars(g_stdout, valstr, -1, NULL, NULL);
         g_io_channel_flush(g_stdout, NULL);
         g_free(valstr);
-    } else if (!g_strncasecmp(buf->str, "allowguest", 10)) {
+    } else if (!g_ascii_strncasecmp(buf->str, "allowguest", 10)) {
         gchar* valstr = buf->str + 11;
-        allowguest = g_strncasecmp(valstr, "false", 2);
+        allowguest = g_ascii_strncasecmp(valstr, "false", 2);
         if (!allowguest)
             gtk_widget_hide(GTK_WIDGET(GuestButton));
         else
@@ -627,24 +628,19 @@ key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer window)
 int
 main(int argc, char *argv[])
 {
-    int w, h;
-    gchar * background;
+    gint lw;
 
-    gint lw, lh;
-
-    GtkWidget *loginWindow, *prefBar, *topBar;
+    GtkWidget *loginWindow, *prefBar;
     GdkCursor *normcursor, *busycursor;
     GtkWidget *syslabel, *timelabel;
-    GtkWidget *logo, *EntryBox, *bottom_right;
+    GtkWidget *logo, *EntryBox;
     GtkWidget *timeoutspacer1, *timeoutspacer2, *timeoutlabel;
     GtkWidget *entryspacer1, *entryspacer2;
     GtkWidget *optionico;
     GtkWidget *optionbutton;
     GdkWindow *root;
-    GdkPixbuf *rawpic, *pix;
-    GdkPixmap *pic;
-    GdkBitmap *mask;
-    gint width, height, has_bottom_right_image;
+    GdkPixbuf *pix;
+    gint width, height;
     GIOChannel *g_stdin;
     char * ldm_theme;
 
@@ -712,6 +708,9 @@ main(int argc, char *argv[])
         g_timeout_add(30000, (GSourceFunc) update_time, timelabel);
     }
 
+    /**** Create the login window ****/
+    loginWindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+
     /* Create the options button */
     {
 
@@ -727,11 +726,7 @@ main(int argc, char *argv[])
                          G_CALLBACK(popup_menu), loginWindow);
     }
 
-    /**** Unsorted stuff ****/
-
-
     /**** Create the login window ****/
-    loginWindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_window_set_position(GTK_WINDOW(loginWindow), GTK_WIN_POS_CENTER_ALWAYS);
     {
         GtkWidget *guestbox, *guestspacer1, *guestspacer2, *vbox, *vbox2, *hbox;
@@ -747,11 +742,6 @@ main(int argc, char *argv[])
         //gtk_widget_realize(loginWindow);
         gtk_window_set_decorated(GTK_WINDOW (loginWindow), FALSE);
 
-        //pw = width;
-        //ph = height;
-        w = width;
-        h = height;
-
         logo = gtk_image_new_from_file(ldm_theme_file("logo"));
 #ifdef K12LINUX
         if(access(ldm_theme_file("bottom_right"), R_OK) == 0) {
@@ -764,7 +754,6 @@ main(int argc, char *argv[])
 
         pix = gtk_image_get_pixbuf((GtkImage *) logo);
         lw = gdk_pixbuf_get_width(pix);
-        lh = gdk_pixbuf_get_height(pix);
 
 
         vbox = gtk_vbox_new(FALSE, 5);
@@ -852,8 +841,6 @@ main(int argc, char *argv[])
     prefBar = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     {
         GtkWidget *BottomBarBox;
-        GtkWidget *optionbutton_box, *optionbutton_spacer;
-        GtkWidget *bottom_right_box, *bottom_right_spacer;
 
         gtk_widget_set_app_paintable(GTK_WIDGET (prefBar), TRUE);
         g_signal_connect(prefBar, "configure-event",
