@@ -30,12 +30,11 @@
 
 #define _GNU_SOURCE
 
-#include <stdio.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <gtk/gtk.h>
-#include <glib.h>
 #include <glib/gi18n.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+#include <stdio.h>
+#include <stdlib.h>
 
 #include <greeter.h>
 
@@ -70,9 +69,8 @@ update_selected_lang()
         GList *l = NULL;
 
         curr_host =
-            g_hash_table_lookup(ldminfo_hash,
-                                g_list_nth_data(host_list,
-                                                selected_host_id));
+            ldminfo_lookup(g_list_nth_data(host_list,
+                  selected_host_id));
         l = curr_host->languages;
         g_strlcpy(language, g_list_nth_data(l, lang_selected - 1),
                   MAXSTRSZ);
@@ -96,13 +94,11 @@ langwin(GtkWidget * widget, GtkWindow * win)
 
     lang_select = gtk_combo_box_new_text();
 
-    /* 
+    /*
      * Populate lang with default host hash
      */
 
-    curr_host =
-        g_hash_table_lookup(ldminfo_hash,
-                            g_list_nth_data(host_list, selected_host_id));
+    curr_host = ldminfo_lookup(g_list_nth_data(host_list, selected_host_id));
 
     gtk_combo_box_append_text(GTK_COMBO_BOX(lang_select),
                               g_strdup(_("Default")));
