@@ -25,12 +25,15 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 #include "ldm.h"
 #include "ldmgreetercomm.h"
 #include "ldmplugin.h"
 #include "ldminfo.h"
 #include "ldmutils.h"
+#include "logging.h"
 
 GList *host_list = NULL;
 volatile sig_atomic_t unexpected_child = 0;
@@ -89,7 +92,6 @@ void get_ldm_env() {
 int main(int argc, char *argv[]) {
     /* decls */
     gchar *auth_plugin = NULL;
-    gchar *err_msg = NULL;
     struct sigaction action;
 
     /* Init log settings */
@@ -171,7 +173,7 @@ int main(int argc, char *argv[]) {
             cmd = g_strconcat("pref choice;backend;Authentication Backend;Select _Backend ...;session;",
                               backends, "\n", NULL);
             if(ask_greeter(cmd))
-                die("ldm",("%s from greeter failed", cmd));
+                die("ldm", "%s from greeter failed", cmd);
             g_free(backends);
             g_free(cmd);
         }
