@@ -9,12 +9,18 @@
 #include <string.h>
 
 #include "ldmplugin.h"
+#include "ldmgreetercomm.h"
+#include "logging.h"
 
 GTree* plugin_list = NULL;
 gchar** plugin_names = NULL;
 static jmp_buf auth_jmp_buf;
 static gchar* current_plugin = NULL;
 
+static int g_strcmp(gconstpointer a, gconstpointer b) {
+    return strcmp((char*)a, (char*)b);
+}
+
 /*
  * set_current_plugin
  *  Set current plugin name
@@ -150,7 +156,7 @@ int ldm_load_plugins() {
         return 1;
     }
     struct dirent* entry;
-    while (entry = readdir(plugin_dir)) {
+    while ( (entry = readdir(plugin_dir)) ) {
         if ((entry->d_type == DT_REG || entry->d_type == DT_UNKNOWN) && (strstr(entry->d_name, ".so") != NULL)) {
             int name_len = strlen(entry->d_name)+strlen(LDM_PLUG_DIR)+2;
             char* plug_name = (char *) malloc(name_len);
